@@ -264,6 +264,22 @@ gegl_op_class_init (GeglOpClass *klass)
 {
   GeglOperationClass       *operation_class;
   GeglOperationFilterClass *filter_class;
+  gchar                    *composition =
+    "<?xml version='1.0' encoding='UTF-8'?>"
+    "<gegl>"
+    "  <node operation='gegl:crop' width='200' height='200'/>"
+    "  <node operation='gegl:over'>"
+    "    <node operation='gegl:antialias'/>"
+    "    <node operation='gegl:threshold'/>"
+    "    <node operation='gegl:load' path='standard-input.png'/>"
+    "  </node>"
+    "  <node operation='gegl:checkerboard'>"
+    "    <params>"
+    "      <param name='color1'>rgb(0.25,0.25,0.25)</param>"
+    "      <param name='color2'>rgb(0.75,0.75,0.75)</param>"
+    "    </params>"
+    "  </node>"    
+    "</gegl>";
 
   operation_class          = GEGL_OPERATION_CLASS (klass);
   filter_class             = GEGL_OPERATION_FILTER_CLASS (klass);
@@ -277,9 +293,9 @@ gegl_op_class_init (GeglOpClass *klass)
     "title",       _("Scale3X Antialiasing"),
     "categories",  "enhance",
     "license",     "GPL3+",
-    "reference-hash", "457b979c0b7f6ff9b41549e05388e67f",
+    "reference-hash", "0d8c2a49014f6083d0e7f145f541ddc0",
+    "reference-composition", composition,
     "description", _("Antialias using the Scale3X edge-extrapolation algorithm"),
-    "reference-chain",    "load path=images/standard-input.png threshold antialias",
     NULL);
 }
 
